================
From SMILES step
================


.. image:: https://img.shields.io/pypi/v/from_smiles_step.svg
        :target: https://pypi.python.org/pypi/from_smiles_step

.. image:: https://img.shields.io/travis/molssi-seamm/from_smiles_step.svg
        :target: https://travis-ci.org/molssi-seamm/from_smiles_step

.. image:: https://readthedocs.org/projects/from_smiles-step/badge/?version=latest
        :target: https://from_smiles-step.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/molssi-seamm/from_smiles_step/shield.svg
     :target: https://pyup.io/repos/github/molssi-seamm/from_smiles_step/
     :alt: Updates

.. image:: https://codecov.io/gh/molssi-seamm/from_smiles_step/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/molssi-seamm/from_smiles_step


The From SMILES step implements a step in a SEAMM flowchart to create a structure from a SMILES string


* Free software: BSD license
* Documentation: https://from-smiles-step.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

